# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class ClientUserIdConflict(UniversalBaseModel):
    error_type: str
    error_message: str
    user_id: str
    created_on: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..types.payor_code_external_provider import PayorCodeExternalProvider
from ..core.request_options import RequestOptions
from ..types.client_facing_payor_search_response import ClientFacingPayorSearchResponse
from ..core.pydantic_utilities import parse_obj_as
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..types.client_facing_payor_search_response_deprecated import ClientFacingPayorSearchResponseDeprecated
from ..types.client_facing_diagnosis_information import ClientFacingDiagnosisInformation
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class InsuranceClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def search_get_payor_info(
        self,
        *,
        insurance_name: typing.Optional[str] = None,
        provider: typing.Optional[PayorCodeExternalProvider] = None,
        provider_payor_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[ClientFacingPayorSearchResponse]:
        """
        Parameters
        ----------
        insurance_name : typing.Optional[str]

        provider : typing.Optional[PayorCodeExternalProvider]

        provider_payor_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingPayorSearchResponse]
            Successful Response

        Examples
        --------
        from vital import Vital

        client = Vital(
            api_key="YOUR_API_KEY",
        )
        client.insurance.search_get_payor_info()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v3/insurance/search/payor",
            method="GET",
            params={
                "insurance_name": insurance_name,
                "provider": provider,
                "provider_payor_id": provider_payor_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[ClientFacingPayorSearchResponse],
                    parse_obj_as(
                        type_=typing.List[ClientFacingPayorSearchResponse],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def search_payor_info(
        self,
        *,
        insurance_name: typing.Optional[str] = OMIT,
        provider: typing.Optional[PayorCodeExternalProvider] = OMIT,
        provider_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[ClientFacingPayorSearchResponseDeprecated]:
        """
        Parameters
        ----------
        insurance_name : typing.Optional[str]

        provider : typing.Optional[PayorCodeExternalProvider]

        provider_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingPayorSearchResponseDeprecated]
            Successful Response

        Examples
        --------
        from vital import Vital

        client = Vital(
            api_key="YOUR_API_KEY",
        )
        client.insurance.search_payor_info()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v3/insurance/search/payor",
            method="POST",
            json={
                "insurance_name": insurance_name,
                "provider": provider,
                "provider_id": provider_id,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[ClientFacingPayorSearchResponseDeprecated],
                    parse_obj_as(
                        type_=typing.List[ClientFacingPayorSearchResponseDeprecated],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def search_diagnosis(
        self, *, diagnosis_query: str, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[ClientFacingDiagnosisInformation]:
        """
        Parameters
        ----------
        diagnosis_query : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingDiagnosisInformation]
            Successful Response

        Examples
        --------
        from vital import Vital

        client = Vital(
            api_key="YOUR_API_KEY",
        )
        client.insurance.search_diagnosis(
            diagnosis_query="diagnosis_query",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v3/insurance/search/diagnosis",
            method="GET",
            params={
                "diagnosis_query": diagnosis_query,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[ClientFacingDiagnosisInformation],
                    parse_obj_as(
                        type_=typing.List[ClientFacingDiagnosisInformation],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncInsuranceClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def search_get_payor_info(
        self,
        *,
        insurance_name: typing.Optional[str] = None,
        provider: typing.Optional[PayorCodeExternalProvider] = None,
        provider_payor_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[ClientFacingPayorSearchResponse]:
        """
        Parameters
        ----------
        insurance_name : typing.Optional[str]

        provider : typing.Optional[PayorCodeExternalProvider]

        provider_payor_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingPayorSearchResponse]
            Successful Response

        Examples
        --------
        import asyncio

        from vital import AsyncVital

        client = AsyncVital(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.insurance.search_get_payor_info()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v3/insurance/search/payor",
            method="GET",
            params={
                "insurance_name": insurance_name,
                "provider": provider,
                "provider_payor_id": provider_payor_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[ClientFacingPayorSearchResponse],
                    parse_obj_as(
                        type_=typing.List[ClientFacingPayorSearchResponse],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def search_payor_info(
        self,
        *,
        insurance_name: typing.Optional[str] = OMIT,
        provider: typing.Optional[PayorCodeExternalProvider] = OMIT,
        provider_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[ClientFacingPayorSearchResponseDeprecated]:
        """
        Parameters
        ----------
        insurance_name : typing.Optional[str]

        provider : typing.Optional[PayorCodeExternalProvider]

        provider_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingPayorSearchResponseDeprecated]
            Successful Response

        Examples
        --------
        import asyncio

        from vital import AsyncVital

        client = AsyncVital(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.insurance.search_payor_info()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v3/insurance/search/payor",
            method="POST",
            json={
                "insurance_name": insurance_name,
                "provider": provider,
                "provider_id": provider_id,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[ClientFacingPayorSearchResponseDeprecated],
                    parse_obj_as(
                        type_=typing.List[ClientFacingPayorSearchResponseDeprecated],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def search_diagnosis(
        self, *, diagnosis_query: str, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[ClientFacingDiagnosisInformation]:
        """
        Parameters
        ----------
        diagnosis_query : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingDiagnosisInformation]
            Successful Response

        Examples
        --------
        import asyncio

        from vital import AsyncVital

        client = AsyncVital(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.insurance.search_diagnosis(
                diagnosis_query="diagnosis_query",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v3/insurance/search/diagnosis",
            method="GET",
            params={
                "diagnosis_query": diagnosis_query,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    typing.List[ClientFacingDiagnosisInformation],
                    parse_obj_as(
                        type_=typing.List[ClientFacingDiagnosisInformation],  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class MenstrualFlowEntryFlow(str, enum.Enum):
    UNSPECIFIED = "unspecified"
    NONE = "none"
    LIGHT = "light"
    MEDIUM = "medium"
    HEAVY = "heavy"

    def visit(
        self,
        unspecified: typing.Callable[[], T_Result],
        none: typing.Callable[[], T_Result],
        light: typing.Callable[[], T_Result],
        medium: typing.Callable[[], T_Result],
        heavy: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is MenstrualFlowEntryFlow.UNSPECIFIED:
            return unspecified()
        if self is MenstrualFlowEntryFlow.NONE:
            return none()
        if self is MenstrualFlowEntryFlow.LIGHT:
            return light()
        if self is MenstrualFlowEntryFlow.MEDIUM:
            return medium()
        if self is MenstrualFlowEntryFlow.HEAVY:
            return heavy()



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .client_facing_source import ClientFacingSource
from .client_facing_sport import ClientFacingSport
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ClientFacingShallowWorkoutStream(UniversalBaseModel):
    user_id: str = pydantic.Field()
    """
    User id returned by vital create user request. This id should be stored in your database against the user and used for all interactions with the vital api.
    """

    workout_id: str
    provider_id: str
    message: typing.Optional[str] = None
    source: ClientFacingSource = pydantic.Field()
    """
    Source the data has come from.
    """

    sport: typing.Optional[ClientFacingSport] = pydantic.Field(default=None)
    """
    Sport's name
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingForcedExpiratoryVolume1ChangedEventType(str, enum.Enum):
    DAILY_DATA_FORCED_EXPIRATORY_VOLUME_1_CREATED = "daily.data.forced_expiratory_volume_1.created"
    DAILY_DATA_FORCED_EXPIRATORY_VOLUME_1_UPDATED = "daily.data.forced_expiratory_volume_1.updated"

    def visit(
        self,
        daily_data_forced_expiratory_volume_1_created: typing.Callable[[], T_Result],
        daily_data_forced_expiratory_volume_1_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingForcedExpiratoryVolume1ChangedEventType.DAILY_DATA_FORCED_EXPIRATORY_VOLUME_1_CREATED:
            return daily_data_forced_expiratory_volume_1_created()
        if self is ClientFacingForcedExpiratoryVolume1ChangedEventType.DAILY_DATA_FORCED_EXPIRATORY_VOLUME_1_UPDATED:
            return daily_data_forced_expiratory_volume_1_updated()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppointmentStatus(str, enum.Enum):
    CONFIRMED = "confirmed"
    PENDING = "pending"
    IN_PROGRESS = "in_progress"
    COMPLETED = "completed"
    CANCELLED = "cancelled"

    def visit(
        self,
        confirmed: typing.Callable[[], T_Result],
        pending: typing.Callable[[], T_Result],
        in_progress: typing.Callable[[], T_Result],
        completed: typing.Callable[[], T_Result],
        cancelled: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is AppointmentStatus.CONFIRMED:
            return confirmed()
        if self is AppointmentStatus.PENDING:
            return pending()
        if self is AppointmentStatus.IN_PROGRESS:
            return in_progress()
        if self is AppointmentStatus.COMPLETED:
            return completed()
        if self is AppointmentStatus.CANCELLED:
            return cancelled()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingHandwashingChangedEventType(str, enum.Enum):
    DAILY_DATA_HANDWASHING_CREATED = "daily.data.handwashing.created"
    DAILY_DATA_HANDWASHING_UPDATED = "daily.data.handwashing.updated"

    def visit(
        self,
        daily_data_handwashing_created: typing.Callable[[], T_Result],
        daily_data_handwashing_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingHandwashingChangedEventType.DAILY_DATA_HANDWASHING_CREATED:
            return daily_data_handwashing_created()
        if self is ClientFacingHandwashingChangedEventType.DAILY_DATA_HANDWASHING_UPDATED:
            return daily_data_handwashing_updated()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class QuestionType(str, enum.Enum):
    CHOICE = "choice"
    TEXT = "text"
    NUMERIC = "numeric"
    MULTI_CHOICE = "multi_choice"

    def visit(
        self,
        choice: typing.Callable[[], T_Result],
        text: typing.Callable[[], T_Result],
        numeric: typing.Callable[[], T_Result],
        multi_choice: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is QuestionType.CHOICE:
            return choice()
        if self is QuestionType.TEXT:
            return text()
        if self is QuestionType.NUMERIC:
            return numeric()
        if self is QuestionType.MULTI_CHOICE:
            return multi_choice()



# This file was auto-generated by Fern from our API Definition.

from .activity_column_expr import ActivityColumnExpr
from .activity_column_expr_activity import ActivityColumnExprActivity
from .activity_v_2_in_db import ActivityV2InDb
from .add_on_order import AddOnOrder
from .address import Address
from .aggregate_expr import AggregateExpr
from .aggregate_expr_arg import AggregateExprArg
from .aggregate_expr_func import AggregateExprFunc
from .aggregation_response import AggregationResponse
from .aggregation_result import AggregationResult
from .allowed_radius import AllowedRadius
from .answer import Answer
from .ao_e import AoE
from .ao_e_answer import AoEAnswer
from .appointment_availability_slots import AppointmentAvailabilitySlots
from .appointment_booking_request import AppointmentBookingRequest
from .appointment_event_status import AppointmentEventStatus
from .appointment_location import AppointmentLocation
from .appointment_provider import AppointmentProvider
from .appointment_psc_labs import AppointmentPscLabs
from .appointment_reschedule_request import AppointmentRescheduleRequest
from .appointment_service_type import AppointmentServiceType
from .appointment_status import AppointmentStatus
from .appointment_type import AppointmentType
from .area_info import AreaInfo
from .attempt_status import AttemptStatus
from .auth_type import AuthType
from .availability import Availability
from .basal_body_temperature_entry import BasalBodyTemperatureEntry
from .billing import Billing
from .biomarker_result import BiomarkerResult
from .body_column_expr import BodyColumnExpr
from .body_column_expr_body import BodyColumnExprBody
from .body_v_2_in_db import BodyV2InDb
from .bulk_export_connections_response import BulkExportConnectionsResponse
from .bulk_import_connections_response import BulkImportConnectionsResponse
from .cervical_mucus_entry import CervicalMucusEntry
from .cervical_mucus_entry_quality import CervicalMucusEntryQuality
from .chronotype_value_macro_expr import ChronotypeValueMacroExpr
from .client_activity_response import ClientActivityResponse
from .client_body_response import ClientBodyResponse
from .client_facing_a_fib_burden_sample import ClientFacingAFibBurdenSample
from .client_facing_activity import ClientFacingActivity
from .client_facing_activity_changed import ClientFacingActivityChanged
from .client_facing_activity_changed_event_type import ClientFacingActivityChangedEventType
from .client_facing_activity_historical_pull_completed import ClientFacingActivityHistoricalPullCompleted
from .client_facing_afib_burden_changed import ClientFacingAfibBurdenChanged
from .client_facing_afib_burden_changed_event_type import ClientFacingAfibBurdenChangedEventType
from .client_facing_afib_burden_historical_pull_completed import ClientFacingAfibBurdenHistoricalPullCompleted
from .client_facing_api_key import ClientFacingApiKey
from .client_facing_appointment import ClientFacingAppointment
from .client_facing_appointment_cancellation_reason import ClientFacingAppointmentCancellationReason
from .client_facing_appointment_changed import ClientFacingAppointmentChanged
from .client_facing_appointment_changed_event_type import ClientFacingAppointmentChangedEventType
from .client_facing_appointment_event import ClientFacingAppointmentEvent
from .client_facing_at_home_phlebotomy_order import ClientFacingAtHomePhlebotomyOrder
from .client_facing_at_home_phlebotomy_order_details import ClientFacingAtHomePhlebotomyOrderDetails
from .client_facing_basal_body_temperature_changed import ClientFacingBasalBodyTemperatureChanged
from .client_facing_basal_body_temperature_changed_event_type import ClientFacingBasalBodyTemperatureChangedEventType
from .client_facing_basal_body_temperature_historical_pull_completed import (
    ClientFacingBasalBodyTemperatureHistoricalPullCompleted,
)
from .client_facing_basal_body_temperature_sample import ClientFacingBasalBodyTemperatureSample
from .client_facing_blood_oxygen_changed import ClientFacingBloodOxygenChanged
from .client_facing_blood_oxygen_changed_event_type import ClientFacingBloodOxygenChangedEventType
from .client_facing_blood_oxygen_historical_pull_completed import ClientFacingBloodOxygenHistoricalPullCompleted
from .client_facing_blood_oxygen_timeseries import ClientFacingBloodOxygenTimeseries
from .client_facing_blood_pressure_changed import ClientFacingBloodPressureChanged
from .client_facing_blood_pressure_changed_event_type import ClientFacingBloodPressureChangedEventType
from .client_facing_blood_pressure_historical_pull_completed import ClientFacingBloodPressureHistoricalPullCompleted
from .client_facing_blood_pressure_timeseries import ClientFacingBloodPressureTimeseries
from .client_facing_body import ClientFacingBody
from .client_facing_body_changed import ClientFacingBodyChanged
from .client_facing_body_changed_event_type import ClientFacingBodyChangedEventType
from .client_facing_body_fat_timeseries import ClientFacingBodyFatTimeseries
from .client_facing_body_historical_pull_completed import ClientFacingBodyHistoricalPullCompleted
from .client_facing_body_temperature_changed import ClientFacingBodyTemperatureChanged
from .client_facing_body_temperature_changed_event_type import ClientFacingBodyTemperatureChangedEventType
from .client_facing_body_temperature_delta_changed import ClientFacingBodyTemperatureDeltaChanged
from .client_facing_body_temperature_delta_changed_event_type import ClientFacingBodyTemperatureDeltaChangedEventType
from .client_facing_body_temperature_delta_historical_pull_completed import (
    ClientFacingBodyTemperatureDeltaHistoricalPullCompleted,
)
from .client_facing_body_temperature_delta_sample import ClientFacingBodyTemperatureDeltaSample
from .client_facing_body_temperature_delta_sample_sensor_location import (
    ClientFacingBodyTemperatureDeltaSampleSensorLocation,
)
from .client_facing_body_temperature_historical_pull_completed import ClientFacingBodyTemperatureHistoricalPullCompleted
from .client_facing_body_temperature_sample import ClientFacingBodyTemperatureSample
from .client_facing_body_temperature_sample_sensor_location import ClientFacingBodyTemperatureSampleSensorLocation
from .client_facing_body_weight_timeseries import ClientFacingBodyWeightTimeseries
from .client_facing_caffeine_changed import ClientFacingCaffeineChanged
from .client_facing_caffeine_changed_event_type import ClientFacingCaffeineChangedEventType
from .client_facing_caffeine_historical_pull_completed import ClientFacingCaffeineHistoricalPullCompleted
from .client_facing_caffeine_timeseries import ClientFacingCaffeineTimeseries
from .client_facing_calories_active_changed import ClientFacingCaloriesActiveChanged
from .client_facing_calories_active_changed_event_type import ClientFacingCaloriesActiveChangedEventType
from .client_facing_calories_active_historical_pull_completed import ClientFacingCaloriesActiveHistoricalPullCompleted
from .client_facing_calories_active_timeseries import ClientFacingCaloriesActiveTimeseries
from .client_facing_calories_basal_changed import ClientFacingCaloriesBasalChanged
from .client_facing_calories_basal_changed_event_type import ClientFacingCaloriesBasalChangedEventType
from .client_facing_calories_basal_historical_pull_completed import ClientFacingCaloriesBasalHistoricalPullCompleted
from .client_facing_calories_basal_timeseries import ClientFacingCaloriesBasalTimeseries
from .client_facing_carbohydrates_changed import ClientFacingCarbohydratesChanged
from .client_facing_carbohydrates_changed_event_type import ClientFacingCarbohydratesChangedEventType
from .client_facing_carbohydrates_historical_pull_completed import ClientFacingCarbohydratesHistoricalPullCompleted
from .client_facing_carbohydrates_sample import ClientFacingCarbohydratesSample
from .client_facing_cholesterol_changed import ClientFacingCholesterolChanged
from .client_facing_cholesterol_changed_event_type import ClientFacingCholesterolChangedEventType
from .client_facing_cholesterol_historical_pull_completed import ClientFacingCholesterolHistoricalPullCompleted
from .client_facing_cholesterol_timeseries import ClientFacingCholesterolTimeseries
from .client_facing_connection_error_details import ClientFacingConnectionErrorDetails
from .client_facing_connection_error_details_error_type import ClientFacingConnectionErrorDetailsErrorType
from .client_facing_continuous_query_result_table_changed import ClientFacingContinuousQueryResultTableChanged
from .client_facing_critical_result import ClientFacingCriticalResult
from .client_facing_critical_result_identified import ClientFacingCriticalResultIdentified
from .client_facing_daylight_exposure_changed import ClientFacingDaylightExposureChanged
from .client_facing_daylight_exposure_changed_event_type import ClientFacingDaylightExposureChangedEventType
from .client_facing_daylight_exposure_historical_pull_completed import (
    ClientFacingDaylightExposureHistoricalPullCompleted,
)
from .client_facing_daylight_exposure_sample import ClientFacingDaylightExposureSample
from .client_facing_diagnosis_information import ClientFacingDiagnosisInformation
from .client_facing_distance_changed import ClientFacingDistanceChanged
from .client_facing_distance_changed_event_type import ClientFacingDistanceChangedEventType
from .client_facing_distance_historical_pull_completed import ClientFacingDistanceHistoricalPullCompleted
from .client_facing_distance_timeseries import ClientFacingDistanceTimeseries
from .client_facing_electrocardiogram import ClientFacingElectrocardiogram
from .client_facing_electrocardiogram_changed import ClientFacingElectrocardiogramChanged
from .client_facing_electrocardiogram_changed_event_type import ClientFacingElectrocardiogramChangedEventType
from .client_facing_electrocardiogram_classification import ClientFacingElectrocardiogramClassification
from .client_facing_electrocardiogram_historical_pull_completed import (
    ClientFacingElectrocardiogramHistoricalPullCompleted,
)
from .client_facing_electrocardiogram_inconclusive_cause import ClientFacingElectrocardiogramInconclusiveCause
from .client_facing_electrocardiogram_response import ClientFacingElectrocardiogramResponse
from .client_facing_electrocardiogram_source_provider import ClientFacingElectrocardiogramSourceProvider
from .client_facing_electrocardiogram_source_type import ClientFacingElectrocardiogramSourceType
from .client_facing_electrocardiogram_voltage_changed import ClientFacingElectrocardiogramVoltageChanged
from .client_facing_electrocardiogram_voltage_changed_event_type import (
    ClientFacingElectrocardiogramVoltageChangedEventType,
)
from .client_facing_electrocardiogram_voltage_historical_pull_completed import (
    ClientFacingElectrocardiogramVoltageHistoricalPullCompleted,
)
from .client_facing_electrocardiogram_voltage_timeseries import ClientFacingElectrocardiogramVoltageTimeseries
from .client_facing_fall_changed import ClientFacingFallChanged
from .client_facing_fall_changed_event_type import ClientFacingFallChangedEventType
from .client_facing_fall_historical_pull_completed import ClientFacingFallHistoricalPullCompleted
from .client_facing_fall_sample import ClientFacingFallSample
from .client_facing_fat_changed import ClientFacingFatChanged
from .client_facing_fat_changed_event_type import ClientFacingFatChangedEventType
from .client_facing_fat_historical_pull_completed import ClientFacingFatHistoricalPullCompleted
from .client_facing_floors_climbed_changed import ClientFacingFloorsClimbedChanged
from .client_facing_floors_climbed_changed_event_type import ClientFacingFloorsClimbedChangedEventType
from .client_facing_floors_climbed_historical_pull_completed import ClientFacingFloorsClimbedHistoricalPullCompleted
from .client_facing_floors_climbed_timeseries import ClientFacingFloorsClimbedTimeseries
from .client_facing_food import ClientFacingFood
from .client_facing_forced_expiratory_volume_1_changed import ClientFacingForcedExpiratoryVolume1Changed
from .client_facing_forced_expiratory_volume_1_changed_event_type import (
    ClientFacingForcedExpiratoryVolume1ChangedEventType,
)
from .client_facing_forced_expiratory_volume_1_historical_pull_completed import (
    ClientFacingForcedExpiratoryVolume1HistoricalPullCompleted,
)
from .client_facing_forced_expiratory_volume_1_sample import ClientFacingForcedExpiratoryVolume1Sample
from .client_facing_forced_vital_capacity_changed import ClientFacingForcedVitalCapacityChanged
from .client_facing_forced_vital_capacity_changed_event_type import ClientFacingForcedVitalCapacityChangedEventType
from .client_facing_forced_vital_capacity_historical_pull_completed import (
    ClientFacingForcedVitalCapacityHistoricalPullCompleted,
)
from .client_facing_forced_vital_capacity_sample import ClientFacingForcedVitalCapacitySample
from .client_facing_glucose_changed import ClientFacingGlucoseChanged
from .client_facing_glucose_changed_event_type import ClientFacingGlucoseChangedEventType
from .client_facing_glucose_historical_pull_completed import ClientFacingGlucoseHistoricalPullCompleted
from .client_facing_glucose_timeseries import ClientFacingGlucoseTimeseries
from .client_facing_handwashing_changed import ClientFacingHandwashingChanged
from .client_facing_handwashing_changed_event_type import ClientFacingHandwashingChangedEventType
from .client_facing_handwashing_historical_pull_completed import ClientFacingHandwashingHistoricalPullCompleted
from .client_facing_handwashing_sample import ClientFacingHandwashingSample
from .client_facing_heart_rate import ClientFacingHeartRate
from .client_facing_heart_rate_alert_changed import ClientFacingHeartRateAlertChanged
from .client_facing_heart_rate_alert_changed_event_type import ClientFacingHeartRateAlertChangedEventType
from .client_facing_heart_rate_alert_historical_pull_completed import ClientFacingHeartRateAlertHistoricalPullCompleted
from .client_facing_heart_rate_alert_sample import ClientFacingHeartRateAlertSample
from .client_facing_heart_rate_alert_sample_type import ClientFacingHeartRateAlertSampleType
from .client_facing_heart_rate_timeseries import ClientFacingHeartRateTimeseries
from .client_facing_heartrate_changed import ClientFacingHeartrateChanged
from .client_facing_heartrate_changed_event_type import ClientFacingHeartrateChangedEventType
from .client_facing_heartrate_historical_pull_completed import ClientFacingHeartrateHistoricalPullCompleted
from .client_facing_hrv_changed import ClientFacingHrvChanged
from .client_facing_hrv_changed_event_type import ClientFacingHrvChangedEventType
from .client_facing_hrv_historical_pull_completed import ClientFacingHrvHistoricalPullCompleted
from .client_facing_hrv_timeseries import ClientFacingHrvTimeseries
from .client_facing_hypnogram_timeseries import ClientFacingHypnogramTimeseries
from .client_facing_ige_changed import ClientFacingIgeChanged
from .client_facing_ige_changed_event_type import ClientFacingIgeChangedEventType
from .client_facing_ige_historical_pull_completed import ClientFacingIgeHistoricalPullCompleted
from .client_facing_ige_timeseries import ClientFacingIgeTimeseries
from .client_facing_igg_changed import ClientFacingIggChanged
from .client_facing_igg_changed_event_type import ClientFacingIggChangedEventType
from .client_facing_igg_historical_pull_completed import ClientFacingIggHistoricalPullCompleted
from .client_facing_igg_timeseries import ClientFacingIggTimeseries
from .client_facing_inhaler_usage_changed import ClientFacingInhalerUsageChanged
from .client_facing_inhaler_usage_changed_event_type import ClientFacingInhalerUsageChangedEventType
from .client_facing_inhaler_usage_historical_pull_completed import ClientFacingInhalerUsageHistoricalPullCompleted
from .client_facing_inhaler_usage_sample import ClientFacingInhalerUsageSample
from .client_facing_insulin_injection_changed import ClientFacingInsulinInjectionChanged
from .client_facing_insulin_injection_changed_event_type import ClientFacingInsulinInjectionChangedEventType
from .client_facing_insulin_injection_historical_pull_completed import (
    ClientFacingInsulinInjectionHistoricalPullCompleted,
)
from .client_facing_insulin_injection_sample import ClientFacingInsulinInjectionSample
from .client_facing_insulin_injection_sample_type import ClientFacingInsulinInjectionSampleType
from .client_facing_insurance import ClientFacingInsurance
from .client_facing_lab import ClientFacingLab
from .client_facing_lab_location import ClientFacingLabLocation
from .client_facing_lab_test import ClientFacingLabTest
from .client_facing_labs import ClientFacingLabs
from .client_facing_loinc import ClientFacingLoinc
from .client_facing_marker import ClientFacingMarker
from .client_facing_marker_complete import ClientFacingMarkerComplete
from .client_facing_meal_changed import ClientFacingMealChanged
from .client_facing_meal_changed_event_type import ClientFacingMealChangedEventType
from .client_facing_meal_historical_pull_completed import ClientFacingMealHistoricalPullCompleted
from .client_facing_meal_response import ClientFacingMealResponse
from .client_facing_menstrual_cycle import ClientFacingMenstrualCycle
from .client_facing_menstrual_cycle_changed import ClientFacingMenstrualCycleChanged
from .client_facing_menstrual_cycle_changed_event_type import ClientFacingMenstrualCycleChangedEventType
from .client_facing_menstrual_cycle_historical_pull_completed import ClientFacingMenstrualCycleHistoricalPullCompleted
from .client_facing_menstrual_cycle_source_provider import ClientFacingMenstrualCycleSourceProvider
from .client_facing_menstrual_cycle_source_type import ClientFacingMenstrualCycleSourceType
from .client_facing_mindfulness_minutes_changed import ClientFacingMindfulnessMinutesChanged
from .client_facing_mindfulness_minutes_changed_event_type import ClientFacingMindfulnessMinutesChangedEventType
from .client_facing_mindfulness_minutes_historical_pull_completed import (
    ClientFacingMindfulnessMinutesHistoricalPullCompleted,
)
from .client_facing_mindfulness_minutes_timeseries import ClientFacingMindfulnessMinutesTimeseries
from .client_facing_note_changed import ClientFacingNoteChanged
from .client_facing_note_changed_event_type import ClientFacingNoteChangedEventType
from .client_facing_note_historical_pull_completed import ClientFacingNoteHistoricalPullCompleted
from .client_facing_note_sample import ClientFacingNoteSample
from .client_facing_note_sample_tags_item import ClientFacingNoteSampleTagsItem
from .client_facing_order import ClientFacingOrder
from .client_facing_order_changed import ClientFacingOrderChanged
from .client_facing_order_changed_event_type import ClientFacingOrderChangedEventType
from .client_facing_order_details import (
    ClientFacingOrderDetails,
    ClientFacingOrderDetails_AtHomePhlebotomy,
    ClientFacingOrderDetails_Testkit,
    ClientFacingOrderDetails_WalkInTest,
)
from .client_facing_order_event import ClientFacingOrderEvent
from .client_facing_patient_details_compatible import ClientFacingPatientDetailsCompatible
from .client_facing_payor_search_response import ClientFacingPayorSearchResponse
from .client_facing_payor_search_response_deprecated import ClientFacingPayorSearchResponseDeprecated
from .client_facing_peak_expiratory_flow_rate_changed import ClientFacingPeakExpiratoryFlowRateChanged
from .client_facing_peak_expiratory_flow_rate_changed_event_type import (
    ClientFacingPeakExpiratoryFlowRateChangedEventType,
)
from .client_facing_peak_expiratory_flow_rate_historical_pull_completed import (
    ClientFacingPeakExpiratoryFlowRateHistoricalPullCompleted,
)
from .client_facing_peak_expiratory_flow_rate_sample import ClientFacingPeakExpiratoryFlowRateSample
from .client_facing_physician import ClientFacingPhysician
from .client_facing_profile import ClientFacingProfile
from .client_facing_profile_changed import ClientFacingProfileChanged
from .client_facing_profile_changed_event_type import ClientFacingProfileChangedEventType
from .client_facing_profile_historical_pull_completed import ClientFacingProfileHistoricalPullCompleted
from .client_facing_provider import ClientFacingProvider
from .client_facing_provider_connection_created_event import ClientFacingProviderConnectionCreatedEvent
from .client_facing_provider_connection_error_event import ClientFacingProviderConnectionErrorEvent
from .client_facing_provider_detailed import ClientFacingProviderDetailed
from .client_facing_provider_with_status import ClientFacingProviderWithStatus
from .client_facing_resource import ClientFacingResource
from .client_facing_respiratory_rate_changed import ClientFacingRespiratoryRateChanged
from .client_facing_respiratory_rate_changed_event_type import ClientFacingRespiratoryRateChangedEventType
from .client_facing_respiratory_rate_historical_pull_completed import ClientFacingRespiratoryRateHistoricalPullCompleted
from .client_facing_respiratory_rate_timeseries import ClientFacingRespiratoryRateTimeseries
from .client_facing_result import ClientFacingResult
from .client_facing_sample_grouping_keys import ClientFacingSampleGroupingKeys
from .client_facing_shallow_workout_stream import ClientFacingShallowWorkoutStream
from .client_facing_shipment import ClientFacingShipment
from .client_facing_sleep import ClientFacingSleep
from .client_facing_sleep_apnea_alert_changed import ClientFacingSleepApneaAlertChanged
from .client_facing_sleep_apnea_alert_changed_event_type import ClientFacingSleepApneaAlertChangedEventType
from .client_facing_sleep_apnea_alert_historical_pull_completed import (
    ClientFacingSleepApneaAlertHistoricalPullCompleted,
)
from .client_facing_sleep_apnea_alert_sample import ClientFacingSleepApneaAlertSample
from .client_facing_sleep_breathing_disturbance_changed import ClientFacingSleepBreathingDisturbanceChanged
from .client_facing_sleep_breathing_disturbance_changed_event_type import (
    ClientFacingSleepBreathingDisturbanceChangedEventType,
)
from .client_facing_sleep_breathing_disturbance_historical_pull_completed import (
    ClientFacingSleepBreathingDisturbanceHistoricalPullCompleted,
)
from .client_facing_sleep_breathing_disturbance_sample import ClientFacingSleepBreathingDisturbanceSample
from .client_facing_sleep_breathing_disturbance_sample_type import ClientFacingSleepBreathingDisturbanceSampleType
from .client_facing_sleep_changed import ClientFacingSleepChanged
from .client_facing_sleep_changed_event_type import ClientFacingSleepChangedEventType
from .client_facing_sleep_cycle import ClientFacingSleepCycle
from .client_facing_sleep_cycle_changed import ClientFacingSleepCycleChanged
from .client_facing_sleep_cycle_changed_event_type import ClientFacingSleepCycleChangedEventType
from .client_facing_sleep_cycle_historical_pull_completed import ClientFacingSleepCycleHistoricalPullCompleted
from .client_facing_sleep_cycle_source_provider import ClientFacingSleepCycleSourceProvider
from .client_facing_sleep_cycle_source_type import ClientFacingSleepCycleSourceType
from .client_facing_sleep_historical_pull_completed import ClientFacingSleepHistoricalPullCompleted
from .client_facing_sleep_stream import ClientFacingSleepStream
from .client_facing_source import ClientFacingSource
from .client_facing_sport import ClientFacingSport
from .client_facing_stand_duration_changed import ClientFacingStandDurationChanged
from .client_facing_stand_duration_changed_event_type import ClientFacingStandDurationChangedEventType
from .client_facing_stand_duration_historical_pull_completed import ClientFacingStandDurationHistoricalPullCompleted
from .client_facing_stand_duration_sample import ClientFacingStandDurationSample
from .client_facing_stand_hour_changed import ClientFacingStandHourChanged
from .client_facing_stand_hour_changed_event_type import ClientFacingStandHourChangedEventType
from .client_facing_stand_hour_historical_pull_completed import ClientFacingStandHourHistoricalPullCompleted
from .client_facing_stand_hour_sample import ClientFacingStandHourSample
from .client_facing_steps_changed import ClientFacingStepsChanged
from .client_facing_steps_changed_event_type import ClientFacingStepsChangedEventType
from .client_facing_steps_historical_pull_completed import ClientFacingStepsHistoricalPullCompleted
from .client_facing_steps_timeseries import ClientFacingStepsTimeseries
from .client_facing_stream import ClientFacingStream
from .client_facing_stream_altitude import ClientFacingStreamAltitude
from .client_facing_stream_cadence import ClientFacingStreamCadence
from .client_facing_stream_distance import ClientFacingStreamDistance
from .client_facing_stream_heartrate import ClientFacingStreamHeartrate
from .client_facing_stream_lat import ClientFacingStreamLat
from .client_facing_stream_lng import ClientFacingStreamLng
from .client_facing_stream_power import ClientFacingStreamPower
from .client_facing_stream_resistance import ClientFacingStreamResistance
from .client_facing_stream_temperature import ClientFacingStreamTemperature
from .client_facing_stream_velocity_smooth import ClientFacingStreamVelocitySmooth
from .client_facing_stress_level_changed import ClientFacingStressLevelChanged
from .client_facing_stress_level_changed_event_type import ClientFacingStressLevelChangedEventType
from .client_facing_stress_level_historical_pull_completed import ClientFacingStressLevelHistoricalPullCompleted
from .client_facing_stress_level_timeseries import ClientFacingStressLevelTimeseries
from .client_facing_team import ClientFacingTeam
from .client_facing_test_kit_order_details import ClientFacingTestKitOrderDetails
from .client_facing_testkit_order import ClientFacingTestkitOrder
from .client_facing_user import ClientFacingUser
from .client_facing_user_key import ClientFacingUserKey
from .client_facing_uv_exposure_changed import ClientFacingUvExposureChanged
from .client_facing_uv_exposure_changed_event_type import ClientFacingUvExposureChangedEventType
from .client_facing_uv_exposure_historical_pull_completed import ClientFacingUvExposureHistoricalPullCompleted
from .client_facing_uv_exposure_sample import ClientFacingUvExposureSample
from .client_facing_vo_2_max_changed import ClientFacingVo2MaxChanged
from .client_facing_vo_2_max_changed_event_type import ClientFacingVo2MaxChangedEventType
from .client_facing_vo_2_max_historical_pull_completed import ClientFacingVo2MaxHistoricalPullCompleted
from .client_facing_vo_2_max_timeseries import ClientFacingVo2MaxTimeseries
from .client_facing_walk_in_order_details import ClientFacingWalkInOrderDetails
from .client_facing_walk_in_test_order import ClientFacingWalkInTestOrder
from .client_facing_water_changed import ClientFacingWaterChanged
from .client_facing_water_changed_event_type import ClientFacingWaterChangedEventType
from .client_facing_water_historical_pull_completed import ClientFacingWaterHistoricalPullCompleted
from .client_facing_water_timeseries import ClientFacingWaterTimeseries
from .client_facing_weight_changed import ClientFacingWeightChanged
from .client_facing_weight_changed_event_type import ClientFacingWeightChangedEventType
from .client_facing_weight_historical_pull_completed import ClientFacingWeightHistoricalPullCompleted
from .client_facing_wheelchair_push_changed import ClientFacingWheelchairPushChanged
from .client_facing_wheelchair_push_changed_event_type import ClientFacingWheelchairPushChangedEventType
from .client_facing_wheelchair_push_historical_pull_completed import ClientFacingWheelchairPushHistoricalPullCompleted
from .client_facing_wheelchair_push_sample import ClientFacingWheelchairPushSample
from .client_facing_workout import ClientFacingWorkout
from .client_facing_workout_duration_changed import ClientFacingWorkoutDurationChanged
from .client_facing_workout_duration_changed_event_type import ClientFacingWorkoutDurationChangedEventType
from .client_facing_workout_duration_historical_pull_completed import ClientFacingWorkoutDurationHistoricalPullCompleted
from .client_facing_workout_duration_sample import ClientFacingWorkoutDurationSample
from .client_facing_workout_duration_sample_intensity import ClientFacingWorkoutDurationSampleIntensity
from .client_facing_workout_map import ClientFacingWorkoutMap
from .client_facing_workout_stream_changed import ClientFacingWorkoutStreamChanged
from .client_facing_workout_stream_changed_event_type import ClientFacingWorkoutStreamChangedEventType
from .client_facing_workout_stream_historical_pull_completed import ClientFacingWorkoutStreamHistoricalPullCompleted
from .client_facing_workouts_changed import ClientFacingWorkoutsChanged
from .client_facing_workouts_changed_event_type import ClientFacingWorkoutsChangedEventType
from .client_facing_workouts_historical_pull_completed import ClientFacingWorkoutsHistoricalPullCompleted
from .client_sleep_cycle_response import ClientSleepCycleResponse
from .client_sleep_response import ClientSleepResponse
from .client_user_id_conflict import ClientUserIdConflict
from .client_user_id_conflict_response import ClientUserIdConflictResponse
from .client_workout_response import ClientWorkoutResponse
from .company_details import CompanyDetails
from .connected_source_client_facing import ConnectedSourceClientFacing
from .connection_recipe import ConnectionRecipe
from .consent import Consent
from .consent_type import ConsentType
from .continuous_query_result_table_changes import ContinuousQueryResultTableChanges
from .contraceptive_entry import ContraceptiveEntry
from .contraceptive_entry_type import ContraceptiveEntryType
from .date_part_expr import DatePartExpr
from .date_part_expr_arg import DatePartExprArg
from .date_part_expr_date_part import DatePartExprDatePart
from .date_trunc_expr import DateTruncExpr
from .date_trunc_expr_arg import DateTruncExprArg
from .day_slots import DaySlots
from .delegated_flow_type import DelegatedFlowType
from .demo_connection_status import DemoConnectionStatus
from .demo_providers import DemoProviders
from .detected_deviation_entry import DetectedDeviationEntry
from .detected_deviation_entry_deviation import DetectedDeviationEntryDeviation
from .device_v_2_in_db import DeviceV2InDb
from .email_providers import EmailProviders
from .energy import Energy
from .event_destination_preferences import EventDestinationPreferences
from .event_destination_preferences_enabled_item import EventDestinationPreferencesEnabledItem
from .event_destination_preferences_preferred import EventDestinationPreferencesPreferred
from .failure_type import FailureType
from .fallback_birth_date import FallbackBirthDate
from .fallback_time_zone import FallbackTimeZone
from .fats import Fats
from .gender import Gender
from .get_markers_response import GetMarkersResponse
from .get_orders_response import GetOrdersResponse
from .group_key_column_expr import GroupKeyColumnExpr
from .group_key_column_expr_group_key import GroupKeyColumnExprGroupKey
from .grouped_a_fib_burden import GroupedAFibBurden
from .grouped_a_fib_burden_response import GroupedAFibBurdenResponse
from .grouped_basal_body_temperature import GroupedBasalBodyTemperature
from .grouped_basal_body_temperature_response import GroupedBasalBodyTemperatureResponse
from .grouped_blood_oxygen import GroupedBloodOxygen
from .grouped_blood_oxygen_response import GroupedBloodOxygenResponse
from .grouped_blood_pressure import GroupedBloodPressure
from .grouped_blood_pressure_response import GroupedBloodPressureResponse
from .grouped_body_fat import GroupedBodyFat
from .grouped_body_fat_response import GroupedBodyFatResponse
from .grouped_body_temperature import GroupedBodyTemperature
from .grouped_body_temperature_delta import GroupedBodyTemperatureDelta
from .grouped_body_temperature_delta_response import GroupedBodyTemperatureDeltaResponse
from .grouped_body_temperature_response import GroupedBodyTemperatureResponse
from .grouped_body_weight import GroupedBodyWeight
from .grouped_body_weight_response import GroupedBodyWeightResponse
from .grouped_caffeine import GroupedCaffeine
from .grouped_caffeine_response import GroupedCaffeineResponse
from .grouped_calories_active import GroupedCaloriesActive
from .grouped_calories_active_response import GroupedCaloriesActiveResponse
from .grouped_calories_basal import GroupedCaloriesBasal
from .grouped_calories_basal_response import GroupedCaloriesBasalResponse
from .grouped_carbohydrates import GroupedCarbohydrates
from .grouped_carbohydrates_response import GroupedCarbohydratesResponse
from .grouped_cholesterol import GroupedCholesterol
from .grouped_cholesterol_response import GroupedCholesterolResponse
from .grouped_daylight_exposure import GroupedDaylightExposure
from .grouped_daylight_exposure_response import GroupedDaylightExposureResponse
from .grouped_distance import GroupedDistance
from .grouped_distance_response import GroupedDistanceResponse
from .grouped_electrocardiogram_voltage import GroupedElectrocardiogramVoltage
from .grouped_electrocardiogram_voltage_response import GroupedElectrocardiogramVoltageResponse
from .grouped_fall import GroupedFall
from .grouped_fall_response import GroupedFallResponse
from .grouped_floors_climbed import GroupedFloorsClimbed
from .grouped_floors_climbed_response import GroupedFloorsClimbedResponse
from .grouped_forced_expiratory_volume_1 import GroupedForcedExpiratoryVolume1
from .grouped_forced_expiratory_volume_1_response import GroupedForcedExpiratoryVolume1Response
from .grouped_forced_vital_capacity import GroupedForcedVitalCapacity
from .grouped_forced_vital_capacity_response import GroupedForcedVitalCapacityResponse
from .grouped_glucose import GroupedGlucose
from .grouped_glucose_response import GroupedGlucoseResponse
from .grouped_handwashing import GroupedHandwashing
from .grouped_handwashing_response import GroupedHandwashingResponse
from .grouped_heart_rate import GroupedHeartRate
from .grouped_heart_rate_alert import GroupedHeartRateAlert
from .grouped_heart_rate_alert_response import GroupedHeartRateAlertResponse
from .grouped_heart_rate_response import GroupedHeartRateResponse
from .grouped_hrv import GroupedHrv
from .grouped_hrv_response import GroupedHrvResponse
from .grouped_hypnogram import GroupedHypnogram
from .grouped_hypnogram_response import GroupedHypnogramResponse
from .grouped_ige import GroupedIge
from .grouped_ige_response import GroupedIgeResponse
from .grouped_igg import GroupedIgg
from .grouped_igg_response import GroupedIggResponse
from .grouped_inhaler_usage import GroupedInhalerUsage
from .grouped_inhaler_usage_response import GroupedInhalerUsageResponse
from .grouped_insulin_injection import GroupedInsulinInjection
from .grouped_insulin_injection_response import GroupedInsulinInjectionResponse
from .grouped_mindfulness_minutes import GroupedMindfulnessMinutes
from .grouped_mindfulness_minutes_response import GroupedMindfulnessMinutesResponse
from .grouped_note import GroupedNote
from .grouped_note_response import GroupedNoteResponse
from .grouped_peak_expiratory_flow_rate import GroupedPeakExpiratoryFlowRate
from .grouped_peak_expiratory_flow_rate_response import GroupedPeakExpiratoryFlowRateResponse
from .grouped_respiratory_rate import GroupedRespiratoryRate
from .grouped_respiratory_rate_response import GroupedRespiratoryRateResponse
from .grouped_sleep_apnea_alert import GroupedSleepApneaAlert
from .grouped_sleep_apnea_alert_response import GroupedSleepApneaAlertResponse
from .grouped_sleep_breathing_disturbance import GroupedSleepBreathingDisturbance
from .grouped_sleep_breathing_disturbance_response import GroupedSleepBreathingDisturbanceResponse
from .grouped_stand_duration import GroupedStandDuration
from .grouped_stand_duration_response import GroupedStandDurationResponse
from .grouped_stand_hour import GroupedStandHour
from .grouped_stand_hour_response import GroupedStandHourResponse
from .grouped_steps import GroupedSteps
from .grouped_steps_response import GroupedStepsResponse
from .grouped_stress_level import GroupedStressLevel
from .grouped_stress_level_response import GroupedStressLevelResponse
from .grouped_uv_exposure import GroupedUvExposure
from .grouped_uv_exposure_response import GroupedUvExposureResponse
from .grouped_vo_2_max import GroupedVo2Max
from .grouped_vo_2_max_response import GroupedVo2MaxResponse
from .grouped_water import GroupedWater
from .grouped_water_response import GroupedWaterResponse
from .grouped_wheelchair_push import GroupedWheelchairPush
from .grouped_wheelchair_push_response import GroupedWheelchairPushResponse
from .grouped_workout_duration import GroupedWorkoutDuration
from .grouped_workout_duration_response import GroupedWorkoutDurationResponse
from .guarantor_details import GuarantorDetails
from .health_insurance_create_request import HealthInsuranceCreateRequest
from .health_insurance_create_request_back_image import HealthInsuranceCreateRequestBackImage
from .health_insurance_create_request_front_image import HealthInsuranceCreateRequestFrontImage
from .health_insurance_create_request_patient_signature_image import HealthInsuranceCreateRequestPatientSignatureImage
from .historical_pull_completed import HistoricalPullCompleted
from .historical_pull_status import HistoricalPullStatus
from .historical_pull_timeline import HistoricalPullTimeline
from .home_pregnancy_test_entry import HomePregnancyTestEntry
from .home_pregnancy_test_entry_test_result import HomePregnancyTestEntryTestResult
from .home_progesterone_test_entry import HomeProgesteroneTestEntry
from .home_progesterone_test_entry_test_result import HomeProgesteroneTestEntryTestResult
from .http_validation_error import HttpValidationError
from .index_column_expr import IndexColumnExpr
from .index_column_expr_index import IndexColumnExprIndex
from .intermenstrual_bleeding_entry import IntermenstrualBleedingEntry
from .jpeg import Jpeg
from .lab_location_metadata import LabLocationMetadata
from .lab_results_metadata import LabResultsMetadata
from .lab_results_raw import LabResultsRaw
from .lab_results_raw_results import LabResultsRawResults
from .lab_test_collection_method import LabTestCollectionMethod
from .lab_test_generation_method_filter import LabTestGenerationMethodFilter
from .lab_test_resources_response import LabTestResourcesResponse
from .lab_test_sample_type import LabTestSampleType
from .lab_test_status import LabTestStatus
from .labs import Labs
from .last_attempt import LastAttempt
from .libre_config import LibreConfig
from .link_token_exchange_response import LinkTokenExchangeResponse
from .lng_lat import LngLat
from .macros import Macros
from .manual_providers import ManualProviders
from .marker_type import MarkerType
from .meal_in_db_base_client_facing_source import MealInDbBaseClientFacingSource
from .menstrual_cycle_response import MenstrualCycleResponse
from .menstrual_flow_entry import MenstrualFlowEntry
from .menstrual_flow_entry_flow import MenstrualFlowEntryFlow
from .metrics_result import MetricsResult
from .micros import Micros
from .minerals import Minerals
from .missing_biomarker_result import MissingBiomarkerResult
from .o_auth_providers import OAuthProviders
from .order_set_request import OrderSetRequest
from .order_status import OrderStatus
from .order_top_level_status import OrderTopLevelStatus
from .ovulation_test_entry import OvulationTestEntry
from .ovulation_test_entry_test_result import OvulationTestEntryTestResult
from .paginated_users_response import PaginatedUsersResponse
from .parent_biomarker_data import ParentBiomarkerData
from .password_providers import PasswordProviders
from .patient_address import PatientAddress
from .patient_address_compatible import PatientAddressCompatible
from .patient_address_with_validation import PatientAddressWithValidation
from .patient_details_with_validation import PatientDetailsWithValidation
from .payor_code_external_provider import PayorCodeExternalProvider
from .period import Period
from .period_unit import PeriodUnit
from .phlebotomy_area_info import PhlebotomyAreaInfo
from .phlebotomy_provider_info import PhlebotomyProviderInfo
from .physician_create_request import PhysicianCreateRequest
from .physician_create_request_base import PhysicianCreateRequestBase
from .physician_create_request_signature_image import PhysicianCreateRequestSignatureImage
from .placeholder import Placeholder
from .png import Png
from .post_order_response import PostOrderResponse
from .profile_in_db import ProfileInDb
from .provider_connection_created import ProviderConnectionCreated
from .provider_connection_error import ProviderConnectionError
from .provider_link_response import ProviderLinkResponse
from .provider_link_response_state import ProviderLinkResponseState
from .provider_mfa_request import ProviderMfaRequest
from .provider_mfa_request_method import ProviderMfaRequestMethod
from .providers import Providers
from .psc_area_info import PscAreaInfo
from .psc_area_info_details import PscAreaInfoDetails
from .psc_info import PscInfo
from .query import Query
from .query_config import QueryConfig
from .query_config_provider_priority_overrides_item import QueryConfigProviderPriorityOverridesItem
from .query_group_by_item import QueryGroupByItem
from .query_select_item import QuerySelectItem
from .question import Question
from .question_type import QuestionType
from .raw_activity import RawActivity
from .raw_body import RawBody
from .raw_devices import RawDevices
from .raw_profile import RawProfile
from .raw_sleep import RawSleep
from .raw_workout import RawWorkout
from .region import Region
from .relative_timeframe import RelativeTimeframe
from .resend_webhook_response import ResendWebhookResponse
from .resource_availability import ResourceAvailability
from .responsible_relationship import ResponsibleRelationship
from .result_type import ResultType
from .scope_requirements_grants import ScopeRequirementsGrants
from .scope_requirements_str import ScopeRequirementsStr
from .select import Select
from .sexual_activity_entry import SexualActivityEntry
from .shipping_address import ShippingAddress
from .shipping_address_with_validation import ShippingAddressWithValidation
from .single_historical_pull_statistics import SingleHistoricalPullStatistics
from .single_provider_historical_pull_response import SingleProviderHistoricalPullResponse
from .single_resource_statistics import SingleResourceStatistics
from .single_user_historical_pull_response import SingleUserHistoricalPullResponse
from .single_user_resource_response import SingleUserResourceResponse
from .sleep_column_expr import SleepColumnExpr
from .sleep_column_expr_sleep import SleepColumnExprSleep
from .sleep_score_value_macro_expr import SleepScoreValueMacroExpr
from .sleep_summary_state import SleepSummaryState
from .sleep_type import SleepType
from .sleep_v_2_in_db import SleepV2InDb
from .source import Source
from .source_auth_type import SourceAuthType
from .source_link import SourceLink
from .source_type import SourceType
from .team_config import TeamConfig
from .time_slot import TimeSlot
from .timeseries_metric_point import TimeseriesMetricPoint
from .timeseries_resource import TimeseriesResource
from .trace_elements import TraceElements
from .unrecognized_value_macro_expr import UnrecognizedValueMacroExpr
from .us_address import UsAddress
from .user_historical_pulls_response import UserHistoricalPullsResponse
from .user_info import UserInfo
from .user_refresh_error_response import UserRefreshErrorResponse
from .user_refresh_success_response import UserRefreshSuccessResponse
from .user_resources_response import UserResourcesResponse
from .user_sign_in_token_response import UserSignInTokenResponse
from .user_success_response import UserSuccessResponse
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .vital_core_schemas_db_schemas_lab_test_health_insurance_person_details import (
    VitalCoreSchemasDbSchemasLabTestHealthInsurancePersonDetails,
)
from .vital_core_schemas_db_schemas_lab_test_insurance_person_details import (
    VitalCoreSchemasDbSchemasLabTestInsurancePersonDetails,
)
from .vital_sleep_stage import VitalSleepStage
from .vital_token_created_response import VitalTokenCreatedResponse
from .vitamins import Vitamins
from .workout_column_expr import WorkoutColumnExpr
from .workout_column_expr_workout import WorkoutColumnExprWorkout
from .workout_v_2_in_db import WorkoutV2InDb

__all__ = [
    "ActivityColumnExpr",
    "ActivityColumnExprActivity",
    "ActivityV2InDb",
    "AddOnOrder",
    "Address",
    "AggregateExpr",
    "AggregateExprArg",
    "AggregateExprFunc",
    "AggregationResponse",
    "AggregationResult",
    "AllowedRadius",
    "Answer",
    "AoE",
    "AoEAnswer",
    "AppointmentAvailabilitySlots",
    "AppointmentBookingRequest",
    "AppointmentEventStatus",
    "AppointmentLocation",
    "AppointmentProvider",
    "AppointmentPscLabs",
    "AppointmentRescheduleRequest",
    "AppointmentServiceType",
    "AppointmentStatus",
    "AppointmentType",
    "AreaInfo",
    "AttemptStatus",
    "AuthType",
    "Availability",
    "BasalBodyTemperatureEntry",
    "Billing",
    "BiomarkerResult",
    "BodyColumnExpr",
    "BodyColumnExprBody",
    "BodyV2InDb",
    "BulkExportConnectionsResponse",
    "BulkImportConnectionsResponse",
    "CervicalMucusEntry",
    "CervicalMucusEntryQuality",
    "ChronotypeValueMacroExpr",
    "ClientActivityResponse",
    "ClientBodyResponse",
    "ClientFacingAFibBurdenSample",
    "ClientFacingActivity",
    "ClientFacingActivityChanged",
    "ClientFacingActivityChangedEventType",
    "ClientFacingActivityHistoricalPullCompleted",
    "ClientFacingAfibBurdenChanged",
    "ClientFacingAfibBurdenChangedEventType",
    "ClientFacingAfibBurdenHistoricalPullCompleted",
    "ClientFacingApiKey",
    "ClientFacingAppointment",
    "ClientFacingAppointmentCancellationReason",
    "ClientFacingAppointmentChanged",
    "ClientFacingAppointmentChangedEventType",
    "ClientFacingAppointmentEvent",
    "ClientFacingAtHomePhlebotomyOrder",
    "ClientFacingAtHomePhlebotomyOrderDetails",
    "ClientFacingBasalBodyTemperatureChanged",
    "ClientFacingBasalBodyTemperatureChangedEventType",
    "ClientFacingBasalBodyTemperatureHistoricalPullCompleted",
    "ClientFacingBasalBodyTemperatureSample",
    "ClientFacingBloodOxygenChanged",
    "ClientFacingBloodOxygenChangedEventType",
    "ClientFacingBloodOxygenHistoricalPullCompleted",
    "ClientFacingBloodOxygenTimeseries",
    "ClientFacingBloodPressureChanged",
    "ClientFacingBloodPressureChangedEventType",
    "ClientFacingBloodPressureHistoricalPullCompleted",
    "ClientFacingBloodPressureTimeseries",
    "ClientFacingBody",
    "ClientFacingBodyChanged",
    "ClientFacingBodyChangedEventType",
    "ClientFacingBodyFatTimeseries",
    "ClientFacingBodyHistoricalPullCompleted",
    "ClientFacingBodyTemperatureChanged",
    "ClientFacingBodyTemperatureChangedEventType",
    "ClientFacingBodyTemperatureDeltaChanged",
    "ClientFacingBodyTemperatureDeltaChangedEventType",
    "ClientFacingBodyTemperatureDeltaHistoricalPullCompleted",
    "ClientFacingBodyTemperatureDeltaSample",
    "ClientFacingBodyTemperatureDeltaSampleSensorLocation",
    "ClientFacingBodyTemperatureHistoricalPullCompleted",
    "ClientFacingBodyTemperatureSample",
    "ClientFacingBodyTemperatureSampleSensorLocation",
    "ClientFacingBodyWeightTimeseries",
    "ClientFacingCaffeineChanged",
    "ClientFacingCaffeineChangedEventType",
    "ClientFacingCaffeineHistoricalPullCompleted",
    "ClientFacingCaffeineTimeseries",
    "ClientFacingCaloriesActiveChanged",
    "ClientFacingCaloriesActiveChangedEventType",
    "ClientFacingCaloriesActiveHistoricalPullCompleted",
    "ClientFacingCaloriesActiveTimeseries",
    "ClientFacingCaloriesBasalChanged",
    "ClientFacingCaloriesBasalChangedEventType",
    "ClientFacingCaloriesBasalHistoricalPullCompleted",
    "ClientFacingCaloriesBasalTimeseries",
    "ClientFacingCarbohydratesChanged",
    "ClientFacingCarbohydratesChangedEventType",
    "ClientFacingCarbohydratesHistoricalPullCompleted",
    "ClientFacingCarbohydratesSample",
    "ClientFacingCholesterolChanged",
    "ClientFacingCholesterolChangedEventType",
    "ClientFacingCholesterolHistoricalPullCompleted",
    "ClientFacingCholesterolTimeseries",
    "ClientFacingConnectionErrorDetails",
    "ClientFacingConnectionErrorDetailsErrorType",
    "ClientFacingContinuousQueryResultTableChanged",
    "ClientFacingCriticalResult",
    "ClientFacingCriticalResultIdentified",
    "ClientFacingDaylightExposureChanged",
    "ClientFacingDaylightExposureChangedEventType",
    "ClientFacingDaylightExposureHistoricalPullCompleted",
    "ClientFacingDaylightExposureSample",
    "ClientFacingDiagnosisInformation",
    "ClientFacingDistanceChanged",
    "ClientFacingDistanceChangedEventType",
    "ClientFacingDistanceHistoricalPullCompleted",
    "ClientFacingDistanceTimeseries",
    "ClientFacingElectrocardiogram",
    "ClientFacingElectrocardiogramChanged",
    "ClientFacingElectrocardiogramChangedEventType",
    "ClientFacingElectrocardiogramClassification",
    "ClientFacingElectrocardiogramHistoricalPullCompleted",
    "ClientFacingElectrocardiogramInconclusiveCause",
    "ClientFacingElectrocardiogramResponse",
    "ClientFacingElectrocardiogramSourceProvider",
    "ClientFacingElectrocardiogramSourceType",
    "ClientFacingElectrocardiogramVoltageChanged",
    "ClientFacingElectrocardiogramVoltageChangedEventType",
    "ClientFacingElectrocardiogramVoltageHistoricalPullCompleted",
    "ClientFacingElectrocardiogramVoltageTimeseries",
    "ClientFacingFallChanged",
    "ClientFacingFallChangedEventType",
    "ClientFacingFallHistoricalPullCompleted",
    "ClientFacingFallSample",
    "ClientFacingFatChanged",
    "ClientFacingFatChangedEventType",
    "ClientFacingFatHistoricalPullCompleted",
    "ClientFacingFloorsClimbedChanged",
    "ClientFacingFloorsClimbedChangedEventType",
    "ClientFacingFloorsClimbedHistoricalPullCompleted",
    "ClientFacingFloorsClimbedTimeseries",
    "ClientFacingFood",
    "ClientFacingForcedExpiratoryVolume1Changed",
    "ClientFacingForcedExpiratoryVolume1ChangedEventType",
    "ClientFacingForcedExpiratoryVolume1HistoricalPullCompleted",
    "ClientFacingForcedExpiratoryVolume1Sample",
    "ClientFacingForcedVitalCapacityChanged",
    "ClientFacingForcedVitalCapacityChangedEventType",
    "ClientFacingForcedVitalCapacityHistoricalPullCompleted",
    "ClientFacingForcedVitalCapacitySample",
    "ClientFacingGlucoseChanged",
    "ClientFacingGlucoseChangedEventType",
    "ClientFacingGlucoseHistoricalPullCompleted",
    "ClientFacingGlucoseTimeseries",
    "ClientFacingHandwashingChanged",
    "ClientFacingHandwashingChangedEventType",
    "ClientFacingHandwashingHistoricalPullCompleted",
    "ClientFacingHandwashingSample",
    "ClientFacingHeartRate",
    "ClientFacingHeartRateAlertChanged",
    "ClientFacingHeartRateAlertChangedEventType",
    "ClientFacingHeartRateAlertHistoricalPullCompleted",
    "ClientFacingHeartRateAlertSample",
    "ClientFacingHeartRateAlertSampleType",
    "ClientFacingHeartRateTimeseries",
    "ClientFacingHeartrateChanged",
    "ClientFacingHeartrateChangedEventType",
    "ClientFacingHeartrateHistoricalPullCompleted",
    "ClientFacingHrvChanged",
    "ClientFacingHrvChangedEventType",
    "ClientFacingHrvHistoricalPullCompleted",
    "ClientFacingHrvTimeseries",
    "ClientFacingHypnogramTimeseries",
    "ClientFacingIgeChanged",
    "ClientFacingIgeChangedEventType",
    "ClientFacingIgeHistoricalPullCompleted",
    "ClientFacingIgeTimeseries",
    "ClientFacingIggChanged",
    "ClientFacingIggChangedEventType",
    "ClientFacingIggHistoricalPullCompleted",
    "ClientFacingIggTimeseries",
    "ClientFacingInhalerUsageChanged",
    "ClientFacingInhalerUsageChangedEventType",
    "ClientFacingInhalerUsageHistoricalPullCompleted",
    "ClientFacingInhalerUsageSample",
    "ClientFacingInsulinInjectionChanged",
    "ClientFacingInsulinInjectionChangedEventType",
    "ClientFacingInsulinInjectionHistoricalPullCompleted",
    "ClientFacingInsulinInjectionSample",
    "ClientFacingInsulinInjectionSampleType",
    "ClientFacingInsurance",
    "ClientFacingLab",
    "ClientFacingLabLocation",
    "ClientFacingLabTest",
    "ClientFacingLabs",
    "ClientFacingLoinc",
    "ClientFacingMarker",
    "ClientFacingMarkerComplete",
    "ClientFacingMealChanged",
    "ClientFacingMealChangedEventType",
    "ClientFacingMealHistoricalPullCompleted",
    "ClientFacingMealResponse",
    "ClientFacingMenstrualCycle",
    "ClientFacingMenstrualCycleChanged",
    "ClientFacingMenstrualCycleChangedEventType",
    "ClientFacingMenstrualCycleHistoricalPullCompleted",
    "ClientFacingMenstrualCycleSourceProvider",
    "ClientFacingMenstrualCycleSourceType",
    "ClientFacingMindfulnessMinutesChanged",
    "ClientFacingMindfulnessMinutesChangedEventType",
    "ClientFacingMindfulnessMinutesHistoricalPullCompleted",
    "ClientFacingMindfulnessMinutesTimeseries",
    "ClientFacingNoteChanged",
    "ClientFacingNoteChangedEventType",
    "ClientFacingNoteHistoricalPullCompleted",
    "ClientFacingNoteSample",
    "ClientFacingNoteSampleTagsItem",
    "ClientFacingOrder",
    "ClientFacingOrderChanged",
    "ClientFacingOrderChangedEventType",
    "ClientFacingOrderDetails",
    "ClientFacingOrderDetails_AtHomePhlebotomy",
    "ClientFacingOrderDetails_Testkit",
    "ClientFacingOrderDetails_WalkInTest",
    "ClientFacingOrderEvent",
    "ClientFacingPatientDetailsCompatible",
    "ClientFacingPayorSearchResponse",
    "ClientFacingPayorSearchResponseDeprecated",
    "ClientFacingPeakExpiratoryFlowRateChanged",
    "ClientFacingPeakExpiratoryFlowRateChangedEventType",
    "ClientFacingPeakExpiratoryFlowRateHistoricalPullCompleted",
    "ClientFacingPeakExpiratoryFlowRateSample",
    "ClientFacingPhysician",
    "ClientFacingProfile",
    "ClientFacingProfileChanged",
    "ClientFacingProfileChangedEventType",
    "ClientFacingProfileHistoricalPullCompleted",
    "ClientFacingProvider",
    "ClientFacingProviderConnectionCreatedEvent",
    "ClientFacingProviderConnectionErrorEvent",
    "ClientFacingProviderDetailed",
    "ClientFacingProviderWithStatus",
    "ClientFacingResource",
    "ClientFacingRespiratoryRateChanged",
    "ClientFacingRespiratoryRateChangedEventType",
    "ClientFacingRespiratoryRateHistoricalPullCompleted",
    "ClientFacingRespiratoryRateTimeseries",
    "ClientFacingResult",
    "ClientFacingSampleGroupingKeys",
    "ClientFacingShallowWorkoutStream",
    "ClientFacingShipment",
    "ClientFacingSleep",
    "ClientFacingSleepApneaAlertChanged",
    "ClientFacingSleepApneaAlertChangedEventType",
    "ClientFacingSleepApneaAlertHistoricalPullCompleted",
    "ClientFacingSleepApneaAlertSample",
    "ClientFacingSleepBreathingDisturbanceChanged",
    "ClientFacingSleepBreathingDisturbanceChangedEventType",
    "ClientFacingSleepBreathingDisturbanceHistoricalPullCompleted",
    "ClientFacingSleepBreathingDisturbanceSample",
    "ClientFacingSleepBreathingDisturbanceSampleType",
    "ClientFacingSleepChanged",
    "ClientFacingSleepChangedEventType",
    "ClientFacingSleepCycle",
    "ClientFacingSleepCycleChanged",
    "ClientFacingSleepCycleChangedEventType",
    "ClientFacingSleepCycleHistoricalPullCompleted",
    "ClientFacingSleepCycleSourceProvider",
    "ClientFacingSleepCycleSourceType",
    "ClientFacingSleepHistoricalPullCompleted",
    "ClientFacingSleepStream",
    "ClientFacingSource",
    "ClientFacingSport",
    "ClientFacingStandDurationChanged",
    "ClientFacingStandDurationChangedEventType",
    "ClientFacingStandDurationHistoricalPullCompleted",
    "ClientFacingStandDurationSample",
    "ClientFacingStandHourChanged",
    "ClientFacingStandHourChangedEventType",
    "ClientFacingStandHourHistoricalPullCompleted",
    "ClientFacingStandHourSample",
    "ClientFacingStepsChanged",
    "ClientFacingStepsChangedEventType",
    "ClientFacingStepsHistoricalPullCompleted",
    "ClientFacingStepsTimeseries",
    "ClientFacingStream",
    "ClientFacingStreamAltitude",
    "ClientFacingStreamCadence",
    "ClientFacingStreamDistance",
    "ClientFacingStreamHeartrate",
    "ClientFacingStreamLat",
    "ClientFacingStreamLng",
    "ClientFacingStreamPower",
    "ClientFacingStreamResistance",
    "ClientFacingStreamTemperature",
    "ClientFacingStreamVelocitySmooth",
    "ClientFacingStressLevelChanged",
    "ClientFacingStressLevelChangedEventType",
    "ClientFacingStressLevelHistoricalPullCompleted",
    "ClientFacingStressLevelTimeseries",
    "ClientFacingTeam",
    "ClientFacingTestKitOrderDetails",
    "ClientFacingTestkitOrder",
    "ClientFacingUser",
    "ClientFacingUserKey",
    "ClientFacingUvExposureChanged",
    "ClientFacingUvExposureChangedEventType",
    "ClientFacingUvExposureHistoricalPullCompleted",
    "ClientFacingUvExposureSample",
    "ClientFacingVo2MaxChanged",
    "ClientFacingVo2MaxChangedEventType",
    "ClientFacingVo2MaxHistoricalPullCompleted",
    "ClientFacingVo2MaxTimeseries",
    "ClientFacingWalkInOrderDetails",
    "ClientFacingWalkInTestOrder",
    "ClientFacingWaterChanged",
    "ClientFacingWaterChangedEventType",
    "ClientFacingWaterHistoricalPullCompleted",
    "ClientFacingWaterTimeseries",
    "ClientFacingWeightChanged",
    "ClientFacingWeightChangedEventType",
    "ClientFacingWeightHistoricalPullCompleted",
    "ClientFacingWheelchairPushChanged",
    "ClientFacingWheelchairPushChangedEventType",
    "ClientFacingWheelchairPushHistoricalPullCompleted",
    "ClientFacingWheelchairPushSample",
    "ClientFacingWorkout",
    "ClientFacingWorkoutDurationChanged",
    "ClientFacingWorkoutDurationChangedEventType",
    "ClientFacingWorkoutDurationHistoricalPullCompleted",
    "ClientFacingWorkoutDurationSample",
    "ClientFacingWorkoutDurationSampleIntensity",
    "ClientFacingWorkoutMap",
    "ClientFacingWorkoutStreamChanged",
    "ClientFacingWorkoutStreamChangedEventType",
    "ClientFacingWorkoutStreamHistoricalPullCompleted",
    "ClientFacingWorkoutsChanged",
    "ClientFacingWorkoutsChangedEventType",
    "ClientFacingWorkoutsHistoricalPullCompleted",
    "ClientSleepCycleResponse",
    "ClientSleepResponse",
    "ClientUserIdConflict",
    "ClientUserIdConflictResponse",
    "ClientWorkoutResponse",
    "CompanyDetails",
    "ConnectedSourceClientFacing",
    "ConnectionRecipe",
    "Consent",
    "ConsentType",
    "ContinuousQueryResultTableChanges",
    "ContraceptiveEntry",
    "ContraceptiveEntryType",
    "DatePartExpr",
    "DatePartExprArg",
    "DatePartExprDatePart",
    "DateTruncExpr",
    "DateTruncExprArg",
    "DaySlots",
    "DelegatedFlowType",
    "DemoConnectionStatus",
    "DemoProviders",
    "DetectedDeviationEntry",
    "DetectedDeviationEntryDeviation",
    "DeviceV2InDb",
    "EmailProviders",
    "Energy",
    "EventDestinationPreferences",
    "EventDestinationPreferencesEnabledItem",
    "EventDestinationPreferencesPreferred",
    "FailureType",
    "FallbackBirthDate",
    "FallbackTimeZone",
    "Fats",
    "Gender",
    "GetMarkersResponse",
    "GetOrdersResponse",
    "GroupKeyColumnExpr",
    "GroupKeyColumnExprGroupKey",
    "GroupedAFibBurden",
    "GroupedAFibBurdenResponse",
    "GroupedBasalBodyTemperature",
    "GroupedBasalBodyTemperatureResponse",
    "GroupedBloodOxygen",
    "GroupedBloodOxygenResponse",
    "GroupedBloodPressure",
    "GroupedBloodPressureResponse",
    "GroupedBodyFat",
    "GroupedBodyFatResponse",
    "GroupedBodyTemperature",
    "GroupedBodyTemperatureDelta",
    "GroupedBodyTemperatureDeltaResponse",
    "GroupedBodyTemperatureResponse",
    "GroupedBodyWeight",
    "GroupedBodyWeightResponse",
    "GroupedCaffeine",
    "GroupedCaffeineResponse",
    "GroupedCaloriesActive",
    "GroupedCaloriesActiveResponse",
    "GroupedCaloriesBasal",
    "GroupedCaloriesBasalResponse",
    "GroupedCarbohydrates",
    "GroupedCarbohydratesResponse",
    "GroupedCholesterol",
    "GroupedCholesterolResponse",
    "GroupedDaylightExposure",
    "GroupedDaylightExposureResponse",
    "GroupedDistance",
    "GroupedDistanceResponse",
    "GroupedElectrocardiogramVoltage",
    "GroupedElectrocardiogramVoltageResponse",
    "GroupedFall",
    "GroupedFallResponse",
    "GroupedFloorsClimbed",
    "GroupedFloorsClimbedResponse",
    "GroupedForcedExpiratoryVolume1",
    "GroupedForcedExpiratoryVolume1Response",
    "GroupedForcedVitalCapacity",
    "GroupedForcedVitalCapacityResponse",
    "GroupedGlucose",
    "GroupedGlucoseResponse",
    "GroupedHandwashing",
    "GroupedHandwashingResponse",
    "GroupedHeartRate",
    "GroupedHeartRateAlert",
    "GroupedHeartRateAlertResponse",
    "GroupedHeartRateResponse",
    "GroupedHrv",
    "GroupedHrvResponse",
    "GroupedHypnogram",
    "GroupedHypnogramResponse",
    "GroupedIge",
    "GroupedIgeResponse",
    "GroupedIgg",
    "GroupedIggResponse",
    "GroupedInhalerUsage",
    "GroupedInhalerUsageResponse",
    "GroupedInsulinInjection",
    "GroupedInsulinInjectionResponse",
    "GroupedMindfulnessMinutes",
    "GroupedMindfulnessMinutesResponse",
    "GroupedNote",
    "GroupedNoteResponse",
    "GroupedPeakExpiratoryFlowRate",
    "GroupedPeakExpiratoryFlowRateResponse",
    "GroupedRespiratoryRate",
    "GroupedRespiratoryRateResponse",
    "GroupedSleepApneaAlert",
    "GroupedSleepApneaAlertResponse",
    "GroupedSleepBreathingDisturbance",
    "GroupedSleepBreathingDisturbanceResponse",
    "GroupedStandDuration",
    "GroupedStandDurationResponse",
    "GroupedStandHour",
    "GroupedStandHourResponse",
    "GroupedSteps",
    "GroupedStepsResponse",
    "GroupedStressLevel",
    "GroupedStressLevelResponse",
    "GroupedUvExposure",
    "GroupedUvExposureResponse",
    "GroupedVo2Max",
    "GroupedVo2MaxResponse",
    "GroupedWater",
    "GroupedWaterResponse",
    "GroupedWheelchairPush",
    "GroupedWheelchairPushResponse",
    "GroupedWorkoutDuration",
    "GroupedWorkoutDurationResponse",
    "GuarantorDetails",
    "HealthInsuranceCreateRequest",
    "HealthInsuranceCreateRequestBackImage",
    "HealthInsuranceCreateRequestFrontImage",
    "HealthInsuranceCreateRequestPatientSignatureImage",
    "HistoricalPullCompleted",
    "HistoricalPullStatus",
    "HistoricalPullTimeline",
    "HomePregnancyTestEntry",
    "HomePregnancyTestEntryTestResult",
    "HomeProgesteroneTestEntry",
    "HomeProgesteroneTestEntryTestResult",
    "HttpValidationError",
    "IndexColumnExpr",
    "IndexColumnExprIndex",
    "IntermenstrualBleedingEntry",
    "Jpeg",
    "LabLocationMetadata",
    "LabResultsMetadata",
    "LabResultsRaw",
    "LabResultsRawResults",
    "LabTestCollectionMethod",
    "LabTestGenerationMethodFilter",
    "LabTestResourcesResponse",
    "LabTestSampleType",
    "LabTestStatus",
    "Labs",
    "LastAttempt",
    "LibreConfig",
    "LinkTokenExchangeResponse",
    "LngLat",
    "Macros",
    "ManualProviders",
    "MarkerType",
    "MealInDbBaseClientFacingSource",
    "MenstrualCycleResponse",
    "MenstrualFlowEntry",
    "MenstrualFlowEntryFlow",
    "MetricsResult",
    "Micros",
    "Minerals",
    "MissingBiomarkerResult",
    "OAuthProviders",
    "OrderSetRequest",
    "OrderStatus",
    "OrderTopLevelStatus",
    "OvulationTestEntry",
    "OvulationTestEntryTestResult",
    "PaginatedUsersResponse",
    "ParentBiomarkerData",
    "PasswordProviders",
    "PatientAddress",
    "PatientAddressCompatible",
    "PatientAddressWithValidation",
    "PatientDetailsWithValidation",
    "PayorCodeExternalProvider",
    "Period",
    "PeriodUnit",
    "PhlebotomyAreaInfo",
    "PhlebotomyProviderInfo",
    "PhysicianCreateRequest",
    "PhysicianCreateRequestBase",
    "PhysicianCreateRequestSignatureImage",
    "Placeholder",
    "Png",
    "PostOrderResponse",
    "ProfileInDb",
    "ProviderConnectionCreated",
    "ProviderConnectionError",
    "ProviderLinkResponse",
    "ProviderLinkResponseState",
    "ProviderMfaRequest",
    "ProviderMfaRequestMethod",
    "Providers",
    "PscAreaInfo",
    "PscAreaInfoDetails",
    "PscInfo",
    "Query",
    "QueryConfig",
    "QueryConfigProviderPriorityOverridesItem",
    "QueryGroupByItem",
    "QuerySelectItem",
    "Question",
    "QuestionType",
    "RawActivity",
    "RawBody",
    "RawDevices",
    "RawProfile",
    "RawSleep",
    "RawWorkout",
    "Region",
    "RelativeTimeframe",
    "ResendWebhookResponse",
    "ResourceAvailability",
    "ResponsibleRelationship",
    "ResultType",
    "ScopeRequirementsGrants",
    "ScopeRequirementsStr",
    "Select",
    "SexualActivityEntry",
    "ShippingAddress",
    "ShippingAddressWithValidation",
    "SingleHistoricalPullStatistics",
    "SingleProviderHistoricalPullResponse",
    "SingleResourceStatistics",
    "SingleUserHistoricalPullResponse",
    "SingleUserResourceResponse",
    "SleepColumnExpr",
    "SleepColumnExprSleep",
    "SleepScoreValueMacroExpr",
    "SleepSummaryState",
    "SleepType",
    "SleepV2InDb",
    "Source",
    "SourceAuthType",
    "SourceLink",
    "SourceType",
    "TeamConfig",
    "TimeSlot",
    "TimeseriesMetricPoint",
    "TimeseriesResource",
    "TraceElements",
    "UnrecognizedValueMacroExpr",
    "UsAddress",
    "UserHistoricalPullsResponse",
    "UserInfo",
    "UserRefreshErrorResponse",
    "UserRefreshSuccessResponse",
    "UserResourcesResponse",
    "UserSignInTokenResponse",
    "UserSuccessResponse",
    "ValidationError",
    "ValidationErrorLocItem",
    "VitalCoreSchemasDbSchemasLabTestHealthInsurancePersonDetails",
    "VitalCoreSchemasDbSchemasLabTestInsurancePersonDetails",
    "VitalSleepStage",
    "VitalTokenCreatedResponse",
    "Vitamins",
    "WorkoutColumnExpr",
    "WorkoutColumnExprWorkout",
    "WorkoutV2InDb",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabTestsGetPaginatedRequestOrderKey(str, enum.Enum):
    PRICE = "price"
    CREATED_AT = "created_at"
    UPDATED_AT = "updated_at"

    def visit(
        self,
        price: typing.Callable[[], T_Result],
        created_at: typing.Callable[[], T_Result],
        updated_at: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LabTestsGetPaginatedRequestOrderKey.PRICE:
            return price()
        if self is LabTestsGetPaginatedRequestOrderKey.CREATED_AT:
            return created_at()
        if self is LabTestsGetPaginatedRequestOrderKey.UPDATED_AT:
            return updated_at()



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .source_auth_type import SourceAuthType
from .source_type import SourceType
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class Source(UniversalBaseModel):
    name: str
    slug: str
    description: str
    logo: str
    group: typing.Optional[str] = None
    oauth_url: typing.Optional[str] = None
    auth_type: typing.Optional[SourceAuthType] = None
    source_type: typing.Optional[SourceType] = None
    is_active: typing.Optional[bool] = None
    backfill_num_days: typing.Optional[int] = None
    id: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .client_facing_note_changed_event_type import ClientFacingNoteChangedEventType
from .grouped_note import GroupedNote
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class ClientFacingNoteChanged(UniversalBaseModel):
    event_type: ClientFacingNoteChangedEventType
    user_id: str
    client_user_id: str
    team_id: str
    data: GroupedNote

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingDaylightExposureChangedEventType(str, enum.Enum):
    DAILY_DATA_DAYLIGHT_EXPOSURE_CREATED = "daily.data.daylight_exposure.created"
    DAILY_DATA_DAYLIGHT_EXPOSURE_UPDATED = "daily.data.daylight_exposure.updated"

    def visit(
        self,
        daily_data_daylight_exposure_created: typing.Callable[[], T_Result],
        daily_data_daylight_exposure_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingDaylightExposureChangedEventType.DAILY_DATA_DAYLIGHT_EXPOSURE_CREATED:
            return daily_data_daylight_exposure_created()
        if self is ClientFacingDaylightExposureChangedEventType.DAILY_DATA_DAYLIGHT_EXPOSURE_UPDATED:
            return daily_data_daylight_exposure_updated()



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import datetime as dt
from .gender import Gender
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class PatientDetailsWithValidation(UniversalBaseModel):
    """
    Patient details with validation for first_name, last_name, email, and dob.
    """

    first_name: str
    last_name: str
    dob: dt.datetime
    gender: Gender
    phone_number: str
    email: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .client_facing_stream_cadence import ClientFacingStreamCadence
import pydantic
from .client_facing_stream_altitude import ClientFacingStreamAltitude
from .client_facing_stream_velocity_smooth import ClientFacingStreamVelocitySmooth
from .client_facing_stream_heartrate import ClientFacingStreamHeartrate
from .client_facing_stream_lat import ClientFacingStreamLat
from .client_facing_stream_lng import ClientFacingStreamLng
from .client_facing_stream_distance import ClientFacingStreamDistance
from .client_facing_stream_power import ClientFacingStreamPower
from .client_facing_stream_resistance import ClientFacingStreamResistance
from .client_facing_stream_temperature import ClientFacingStreamTemperature
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ClientFacingStream(UniversalBaseModel):
    cadence: typing.Optional[ClientFacingStreamCadence] = pydantic.Field(default=None)
    """
    RPM for cycling, Steps per minute for running
    """

    time: typing.Optional[typing.List[int]] = pydantic.Field(default=None)
    """
    Corresponding time stamp in unix time for datapoint
    """

    altitude: typing.Optional[ClientFacingStreamAltitude] = pydantic.Field(default=None)
    """
    Data points for altitude
    """

    velocity_smooth: typing.Optional[ClientFacingStreamVelocitySmooth] = pydantic.Field(default=None)
    """
    Velocity in m/s
    """

    heartrate: typing.Optional[ClientFacingStreamHeartrate] = pydantic.Field(default=None)
    """
    Heart rate in bpm
    """

    lat: typing.Optional[ClientFacingStreamLat] = pydantic.Field(default=None)
    """
    Latitude for data point
    """

    lng: typing.Optional[ClientFacingStreamLng] = pydantic.Field(default=None)
    """
    Longitude for data point
    """

    distance: typing.Optional[ClientFacingStreamDistance] = pydantic.Field(default=None)
    """
    Cumulated distance for exercise
    """

    power: typing.Optional[ClientFacingStreamPower] = pydantic.Field(default=None)
    """
    Power in watts
    """

    resistance: typing.Optional[ClientFacingStreamResistance] = pydantic.Field(default=None)
    """
    Resistance on bike
    """

    temperature: typing.Optional[ClientFacingStreamTemperature] = pydantic.Field(default=None)
    """
    Temperature stream measured by device in Celsius
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import datetime as dt
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class TimeSlot(UniversalBaseModel):
    booking_key: typing.Optional[str] = None
    start: dt.datetime = pydantic.Field()
    """
    Time is in UTC
    """

    end: dt.datetime = pydantic.Field()
    """
    Time is in UTC
    """

    expires_at: typing.Optional[dt.datetime] = None
    price: float
    is_priority: bool
    num_appointments_available: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .client_facing_api_key import ClientFacingApiKey
from .team_config import TeamConfig
from .delegated_flow_type import DelegatedFlowType
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ClientFacingTeam(UniversalBaseModel):
    """
    [Deprecated] GET /v2/team is in the process of being removed.
    Neither customers nor Dashboard should retrieve team settings and metadata directly.

    All must migrate to the Team endpoints of the Org Management API.
    """

    id: str
    org_id: str
    name: str
    svix_app_id: typing.Optional[str] = None
    client_id: typing.Optional[str] = None
    client_secret: typing.Optional[str] = None
    airtable_api_key: typing.Optional[str] = None
    airtable_base_id: typing.Optional[str] = None
    webhook_secret: typing.Optional[str] = None
    api_key: typing.Optional[str] = None
    api_keys: typing.Optional[typing.List[ClientFacingApiKey]] = None
    configuration: typing.Optional[TeamConfig] = None
    testkits_texts_enabled: bool
    lab_tests_patient_communication_enabled: bool
    lab_tests_patient_sms_communication_enabled: bool
    lab_tests_patient_email_communication_enabled: bool
    logo_url: typing.Optional[str] = None
    delegated_flow: DelegatedFlowType

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingSleepBreathingDisturbanceSampleType(str, enum.Enum):
    ELEVATED = "elevated"
    NOT_ELEVATED = "not_elevated"

    def visit(self, elevated: typing.Callable[[], T_Result], not_elevated: typing.Callable[[], T_Result]) -> T_Result:
        if self is ClientFacingSleepBreathingDisturbanceSampleType.ELEVATED:
            return elevated()
        if self is ClientFacingSleepBreathingDisturbanceSampleType.NOT_ELEVATED:
            return not_elevated()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingOrderChangedEventType(str, enum.Enum):
    LABTEST_ORDER_CREATED = "labtest.order.created"
    LABTEST_ORDER_UPDATED = "labtest.order.updated"

    def visit(
        self, labtest_order_created: typing.Callable[[], T_Result], labtest_order_updated: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is ClientFacingOrderChangedEventType.LABTEST_ORDER_CREATED:
            return labtest_order_created()
        if self is ClientFacingOrderChangedEventType.LABTEST_ORDER_UPDATED:
            return labtest_order_updated()



# This file was auto-generated by Fern from our API Definition.

import typing

# File typing inspired by the flexibility of types within the httpx library
# https://github.com/encode/httpx/blob/master/httpx/_types.py
FileContent = typing.Union[typing.IO[bytes], bytes, str]
File = typing.Union[
    # file (or bytes)
    FileContent,
    # (filename, file (or bytes))
    typing.Tuple[typing.Optional[str], FileContent],
    # (filename, file (or bytes), content_type)
    typing.Tuple[typing.Optional[str], FileContent, typing.Optional[str]],
    # (filename, file (or bytes), content_type, headers)
    typing.Tuple[
        typing.Optional[str],
        FileContent,
        typing.Optional[str],
        typing.Mapping[str, str],
    ],
]


def convert_file_dict_to_httpx_tuples(
    d: typing.Dict[str, typing.Union[File, typing.List[File]]],
) -> typing.List[typing.Tuple[str, File]]:
    """
    The format we use is a list of tuples, where the first element is the
    name of the file and the second is the file object. Typically HTTPX wants
    a dict, but to be able to send lists of files, you have to use the list
    approach (which also works for non-lists)
    https://github.com/encode/httpx/pull/1032
    """

    httpx_tuples = []
    for key, file_like in d.items():
        if isinstance(file_like, list):
            for file_like_item in file_like:
                httpx_tuples.append((key, file_like_item))
        else:
            httpx_tuples.append((key, file_like))
    return httpx_tuples
